# BetterStatcord.py
A better Statcord API library for Python + Discord.py

## Advantages
- **It's blazin fast**: The official library is full of inefficient, slow, and unnecessary code which does nothing **except slow your bot down**.
- **Cleaner and smaller codebase**: BetterStatcord.py is smaller and cleaner, making it much more reliable and understandable.
- **Easier to use**: For its basic functionality, all you need is **one** line of code to set it up!
- **More accurate**: This library has more accurate statistics than the official one.

## Examples
- Check out the [examples folder](https://github.com/Iapetus-11/betterstatcord.py/tree/main/examples)
